==> arcproxyutilities-1.0.1.tar.gz: arcproxyutilities-1.0.1/src/arcproxyutilities/constants.py <==
CLIENTPROXY_CLIENT_ID = '04b07795-8ddb-461a-bbee-02f9e1bf7b46'
API_CALL_RETRIES = 20
CSP_REFRESH_TIME = 300
Azure_PublicCloudName = 'AZUREPUBLICCLOUD'
Azure_USGovCloudName = 'AZUREUSGOVERNMENTCLOUD'
Azure_DogfoodCloudName = 'AZUREDOGFOOD'
PublicCloud_OriginalName = 'AZURECLOUD'
USGovCloud_OriginalName = 'AZUREUSGOVERNMENT'
Public_RMEndpoint = 'https://management.azure.com/'
Dogfood_RMEndpoint = 'https://api-dogfood.resources.windows-int.net/'
USGov_RMEndpoint = 'https://management.usgovcloudapi.net/'
CSP_Storage_Url = "https://k8sconnectcsp.azureedge.net/"
List_Ingress_Gateway_Credential_Api_Version = "2021-10-01-privatepreview"
ProxyConfigurations_Kubeconfig_Api_Version = "2021-10-01"
Post_Relay_Auth_Info = "Error while posting relay and static authentication details to proxy process"
Load_Kubeconfig_Fault_Type = "Error while loading kubeconfig"
Merge_Kubeconfig_Fault_Type = "Error while merging kubeconfig."
Failed_To_Merge_Credentials_Fault_Type = "failed-to-merge-credentials"
Failed_To_Load_K8s_Configuration_Fault_Type = "failed-to-load-kubernetes-configuration"
Unsupported_Fault_Type = "Error while checking operating system.Unsupported OS detected."
Download_Exe_Fault_Type = "Error while downloading client proxy executable from storage account"
Create_Directory_Fault_Type = "Error while creating directory for placing the executable"
Create_CSPExe_Fault_Type = "Error while creating csp executable"
Remove_Config_Fault_Type = "Error while removing old csp config"
Load_Creds_Fault_Type = "Error while loading accessToken.json"
Creds_NotFound_Fault_Type = "Credentials of user not found"
Create_Config_Fault_Type = "Error while creating config file for proxy"
Proxy_Closed_Externally_Fault_Type = "Proxy closed externally."
Get_Ingress_Gateway_Credentials_Fault_Type = "failed-to-get-list-ingress-gateway-credentials"
Run_Clientproxy_Fault_Type = "Error while starting client proxy process."
Failed_To_Merge_Kubeconfig_File = "failed-to-merge-kubeconfig-file"
Different_Object_With_Same_Name_Fault_Type = "Kubeconfig has an object with same name"
Kubeconfig_Failed_To_Load_Fault_Type = "failed-to-load-kubeconfig-file"
Post_RefreshToken_Fault_Type = "Error while posting refresh token details to proxy process"
Client_Proxy_Port_Fault_Type = "Client proxy port was in use."
Port_Check_Fault_Type = "Error while checking if port is in use."

==> arcproxyutilities-1.0.2.tar.gz: arcproxyutilities-1.0.2/src/arcproxyutilities/constants.py <==
CLIENTPROXY_CLIENT_ID = '04b07795-8ddb-461a-bbee-02f9e1bf7b46'
API_CALL_RETRIES = 20
CSP_REFRESH_TIME = 300
Azure_PublicCloudName = 'AZUREPUBLICCLOUD'
Azure_USGovCloudName = 'AZUREUSGOVERNMENTCLOUD'
Azure_DogfoodCloudName = 'AZUREDOGFOOD'
PublicCloud_OriginalName = 'AZURECLOUD'
USGovCloud_OriginalName = 'AZUREUSGOVERNMENT'
Public_RMEndpoint = 'https://management.azure.com/'
Dogfood_RMEndpoint = 'https://api-dogfood.resources.windows-int.net/'
USGov_RMEndpoint = 'https://management.usgovcloudapi.net/'
CSP_Storage_Url = "https://k8sconnectcsp.azureedge.net/"
List_Ingress_Gateway_Credential_Api_Version = "2021-10-01-privatepreview"
ProxyConfigurations_Kubeconfig_Api_Version = "2021-10-01"
Post_Relay_Auth_Info = "Error while posting relay and static authentication details to proxy process"
Load_Kubeconfig_Fault_Type = "Error while loading kubeconfig"
Merge_Kubeconfig_Fault_Type = "Error while merging kubeconfig."
Failed_To_Merge_Credentials_Fault_Type = "failed-to-merge-credentials"
Failed_To_Load_K8s_Configuration_Fault_Type = "failed-to-load-kubernetes-configuration"
Unsupported_Fault_Type = "Error while checking operating system.Unsupported OS detected."
Download_Exe_Fault_Type = "Error while downloading client proxy executable from storage account"
Create_Directory_Fault_Type = "Error while creating directory for placing the executable"
Create_CSPExe_Fault_Type = "Error while creating csp executable"
Remove_Config_Fault_Type = "Error while removing old csp config"
Load_Creds_Fault_Type = "Error while loading accessToken.json"
Creds_NotFound_Fault_Type = "Credentials of user not found"
Create_Config_Fault_Type = "Error while creating config file for proxy"
Proxy_Closed_Externally_Fault_Type = "Proxy closed externally."
Get_Ingress_Gateway_Credentials_Fault_Type = "failed-to-get-list-ingress-gateway-credentials"
Run_Clientproxy_Fault_Type = "Error while starting client proxy process."
Failed_To_Merge_Kubeconfig_File = "failed-to-merge-kubeconfig-file"
Different_Object_With_Same_Name_Fault_Type = "Kubeconfig has an object with same name"
Kubeconfig_Failed_To_Load_Fault_Type = "failed-to-load-kubeconfig-file"
Post_RefreshToken_Fault_Type = "Error while posting refresh token details to proxy process"
Client_Proxy_Port_Fault_Type = "Client proxy port was in use."
Port_Check_Fault_Type = "Error while checking if port is in use."
Get_PublicKey_Info_Fault_Type = 'Error while fetching the PoP publickey information from client proxy'
PoP_Public_Key_Expried_Fault_Type = 'The PoP public key used to generate the at has expired'
Post_AT_To_ClientProxy_Failed_Fault_Type = 'Failed to post access token to client proxy'
PublicKey_Export_Fault_Type = 'publickey-export-error'
KAP_1P_Server_App_Scope = "6256c85f-0aad-4d50-b960-e6e9b21efe35/.default"
KAP_1P_Server_AppId = "6256c85f-0aad-4d50-b960-e6e9b21efe35"
AZ_CLI_ADAL_TO_MSAL_MIGRATE_VERSION = '2.30.0'
